@@ -180,10 +180,10 @@ if you prefer to blend Standard and Modus into a single group, enable
        (t :underline ,border-mode-line-active)))))
 
 (defconst standard-themes-with-properties
-  '((standard-light standard-themes "Like the unthemed light Emacs, but more consistent." light modus-operandi-palette standard-light-palette standard-light-palette-overrides)
-    (standard-light-tinted standard-themes "Light ochre variant of the standard-light theme." light modus-operandi-tinted-palette standard-light-tinted-palette standard-light-tinted-palette-overrides)
-    (standard-dark standard-themes "Like the unthemed dark Emacs, but more consistent." dark modus-vivendi-palette standard-dark-palette standard-dark-palette-overrides)
-    (standard-dark-tinted standard-themes "Night sky variant of standard-dark theme." dark modus-vivendi-tinted-palette standard-dark-tinted-palette standard-dark-tinted-palette-overrides)))
+  '((standard-light standard-themes "Like the unthemed light Emacs, but more consistent." light standard-light-palette nil standard-light-palette-overrides)
+    (standard-light-tinted standard-themes "Light ochre variant of the standard-light theme." light standard-light-tinted-palette nil standard-light-tinted-palette-overrides)
+    (standard-dark standard-themes "Like the unthemed dark Emacs, but more consistent." dark standard-dark-palette nil standard-dark-palette-overrides)
+    (standard-dark-tinted standard-themes "Night sky variant of standard-dark theme." dark standard-dark-tinted-palette nil standard-dark-tinted-palette-overrides)))
 
 (defvar standard-themes--declared-p nil)
 
@@ -261,7 +261,7 @@ They are all designed to only consider Standard themes."
   :init-value nil)
 
 (cl-defmethod modus-themes-get-themes (&context (standard-themes-take-over-modus-themes-mode (eql t)))
-  "Return list of Standard themes, per `standard-themes-take-over-modus-themes-mode'."
+  "Return Standard themes per `standard-themes-take-over-modus-themes-mode'."
   (if-let* ((themes (modus-themes-get-all-known-themes 'standard-themes))
             (sorted-a-z (sort themes #'string-lessp))
             (sorted-light-dark (modus-themes-sort sorted-a-z 'light)))
